@@ -1,11 +1,6 @@
 package Tapper::Cmd::Cobbler;
-BEGIN {
-  $Tapper::Cmd::Cobbler::AUTHORITY = 'cpan:TAPPER';
-}
-{
-  $Tapper::Cmd::Cobbler::VERSION = '4.1.8';
-}
-
+our $AUTHORITY = 'cpan:TAPPER';
+$Tapper::Cmd::Cobbler::VERSION = '5.0.0';
 use warnings;
 use strict;
 
@@ -135,7 +130,7 @@ __END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -226,13 +221,23 @@ Copyright 2012 AMD OSRC Tapper Team, all rights reserved.
 
 This program is released under the following license: freebsd
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 AMD OSRC Tapper Team <tapper@amd64.org>
 
+=item *
+
+Tapper Team <tapper-ops@amazon.com>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2013 by Advanced Micro Devices, Inc..
+This software is Copyright (c) 2016 by Advanced Micro Devices, Inc..
 
 This is free software, licensed under:
 
