@@ -1,12 +1,7 @@
 package Tapper::Cmd::DbDeploy;
-BEGIN {
-  $Tapper::Cmd::DbDeploy::AUTHORITY = 'cpan:TAPPER';
-}
-{
-  $Tapper::Cmd::DbDeploy::VERSION = '4.1.8';
-}
+our $AUTHORITY = 'cpan:TAPPER';
 # ABSTRACT: Tapper - Backend functions for DB deployment
-
+$Tapper::Cmd::DbDeploy::VERSION = '5.0.0';
 use 5.010;
 use strict;
 use warnings;
@@ -14,7 +9,6 @@ use warnings;
 use Moose;
 use Tapper::Config;
 use Tapper::Schema::TestrunDB;
-use Tapper::Schema::ReportsDB;
 
 extends 'Tapper::Cmd';
 
@@ -81,8 +75,7 @@ sub dbdeploy
                 open STDERR, '>', \$stderr;
 
                 my $schema;
-                $schema = Tapper::Schema::TestrunDB->connect ($dsn, $user, $pw) if $db eq 'TestrunDB';
-                $schema = Tapper::Schema::ReportsDB->connect ($dsn, $user, $pw) if $db eq 'ReportsDB';
+                $schema = Tapper::Schema::TestrunDB->connect ($dsn, $user, $pw);
                 $schema->deploy({ add_drop_table => 1 }); # may fail, does not provide correct order to drop tables
                 insert_initial_values($schema, $db);
         }
@@ -95,7 +88,7 @@ __END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -107,7 +100,6 @@ This module provides functions to initially set up Tapper in C<$HOME/.tapper/>.
 
     use Tapper::Cmd::DbDeploy;
     my $cmd = Tapper::Cmd::DbDeploy->new;
-    $cmd->dbdeploy("ReportsDB");
     $cmd->dbdeploy("TestrunDB");
 
 =head1 NAME
@@ -130,13 +122,23 @@ Connection info is determined via Tapper::Config.
 
 TODO: still an interactive tool but interactivity should be migrated back into Tapper::CLI::*.
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 AMD OSRC Tapper Team <tapper@amd64.org>
 
+=item *
+
+Tapper Team <tapper-ops@amazon.com>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2013 by Advanced Micro Devices, Inc..
+This software is Copyright (c) 2016 by Advanced Micro Devices, Inc..
 
 This is free software, licensed under:
 
