@@ -1,12 +1,7 @@
 package Tapper::Cmd::Init;
-BEGIN {
-  $Tapper::Cmd::Init::AUTHORITY = 'cpan:TAPPER';
-}
-{
-  $Tapper::Cmd::Init::VERSION = '4.1.8';
-}
+our $AUTHORITY = 'cpan:TAPPER';
 # ABSTRACT: Tapper - Backend functions for initially setting up Tapper
-
+$Tapper::Cmd::Init::VERSION = '5.0.0';
 use 5.010;
 use strict;
 use warnings;
@@ -73,18 +68,16 @@ sub dbdeploy
 {
         Tapper::Config::_switch_context; # reload config
 
-        foreach my $db (qw(TestrunDB ReportsDB)) {
-                my $dsn = Tapper::Config->subconfig->{database}{$db}{dsn};
-                my ($scheme, $driver, $attr_string, $attr_hash, $driver_dsn) = DBI->parse_dsn($dsn)
-                 or die "Can't parse DBI DSN '$dsn'";
-                if ($driver eq "SQLite") {
-                        my ($dbname) = $driver_dsn =~ /dbname=(.*)/;
-                        if (! -e $dbname) {
-                                my $cmd = Tapper::Cmd::DbDeploy->new;
-                                $cmd->dbdeploy($db);
-                        } else {
-                                say "SKIP    $dbname - already exists";
-                        }
+        my $dsn = Tapper::Config->subconfig->{database}{TestrunDB}{dsn};
+        my ($scheme, $driver, $attr_string, $attr_hash, $driver_dsn) = DBI->parse_dsn($dsn)
+         or die "Can't parse DBI DSN '$dsn'";
+        if ($driver eq "SQLite") {
+                my ($dbname) = $driver_dsn =~ /dbname=(.*)/;
+                if (! -e $dbname) {
+                        my $cmd = Tapper::Cmd::DbDeploy->new;
+                        $cmd->dbdeploy('TestrunDB');
+                } else {
+                        say "SKIP    $dbname - already exists";
                 }
         }
 }
@@ -151,7 +144,7 @@ __END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -189,13 +182,23 @@ Initialize databases in $HOME/.tapper/
 
 Initialize $HOME/.tapper/
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 AMD OSRC Tapper Team <tapper@amd64.org>
 
+=item *
+
+Tapper Team <tapper-ops@amazon.com>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2013 by Advanced Micro Devices, Inc..
+This software is Copyright (c) 2016 by Advanced Micro Devices, Inc..
 
 This is free software, licensed under:
 
