@@ -1,10 +1,6 @@
 package Tapper::Cmd::Notification;
-BEGIN {
-  $Tapper::Cmd::Notification::AUTHORITY = 'cpan:TAPPER';
-}
-{
-  $Tapper::Cmd::Notification::VERSION = '4.1.8';
-}
+our $AUTHORITY = 'cpan:TAPPER';
+$Tapper::Cmd::Notification::VERSION = '5.0.0';
 use Moose;
 
 use Tapper::Model 'model';
@@ -19,7 +15,7 @@ sub get_user
         my ($self, $data) = @_;
         if (not $data->{owner_id}) {
                 my $login = $data->{owner_login} || $ENV{USER};
-                my $owner = model('ReportsDB')->resultset('Owner')->search({login => $login}, {rows => 1})->first;
+                my $owner = model('TestrunDB')->resultset('Owner')->search({login => $login}, {rows => 1})->first;
                 if (not $owner) {
                         die "User '$login' does not exist in the database. Please create this user first.\n";
                 }
@@ -38,7 +34,7 @@ sub add {
 
         $data = $self->get_user($data);
 
-        my $notification = model('ReportsDB')->resultset('Notification')->new($data);
+        my $notification = model('TestrunDB')->resultset('Notification')->new($data);
         $notification->insert;
 
         return $notification->id;
@@ -48,7 +44,7 @@ sub add {
 sub list
 {
         my ($self, $search) = @_;
-        return model('ReportsDB')->resultset('Notification')->search($search, { result_class => 'DBIx::Class::ResultClass::HashRefInflator' });
+        return model('TestrunDB')->resultset('Notification')->search($search, { result_class => 'DBIx::Class::ResultClass::HashRefInflator' });
 }
 
 
@@ -56,7 +52,7 @@ sub list
 sub update {
         my ($self, $id, $data) = @_;
 
-        my $notification = model('ReportsDB')->resultset('Notification')->find($id);
+        my $notification = model('TestrunDB')->resultset('Notification')->find($id);
         die "Notification subscription with id $id not found\n" if not $notification;
         die "Did not get a hash with data for updating notification subscription with id '$id'" unless ref $data eq 'HASH';
 
@@ -74,7 +70,7 @@ sub update {
 
 sub del {
         my ($self, $id) = @_;
-        my $notification = model('ReportsDB')->resultset('Notification')->find($id);
+        my $notification = model('TestrunDB')->resultset('Notification')->find($id);
         die qq(No notification subscription with id "$id" found) if not $notification;;
         $notification->delete();
         return 0;
@@ -89,7 +85,7 @@ __END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -181,13 +177,23 @@ Copyright 2012 AMD OSRC Tapper Team, all rights reserved.
 
 This program is released under the following license: freebsd
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 AMD OSRC Tapper Team <tapper@amd64.org>
 
+=item *
+
+Tapper Team <tapper-ops@amazon.com>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2013 by Advanced Micro Devices, Inc..
+This software is Copyright (c) 2016 by Advanced Micro Devices, Inc..
 
 This is free software, licensed under:
 
