@@ -1,13 +1,8 @@
 package Tapper::Cmd::Precondition;
-BEGIN {
-  $Tapper::Cmd::Precondition::AUTHORITY = 'cpan:TAPPER';
-}
-{
-  $Tapper::Cmd::Precondition::VERSION = '4.1.8';
-}
+our $AUTHORITY = 'cpan:TAPPER';
+$Tapper::Cmd::Precondition::VERSION = '5.0.0';
 use Moose;
 
-use Tapper::Model 'model';
 use YAML::Syck;
 use Kwalify;
 
@@ -47,25 +42,23 @@ sub die_on_invalid_precondition
 }
 
 
-
-
 sub add {
         my ($self, $input, $schema) = @_;
         if (ref $input eq 'ARRAY') {
                 $self->die_on_invalid_precondition($input, $schema);
-                return model('TestrunDB')->resultset('Precondition')->add($input);
+                return $self->schema->resultset('Precondition')->add($input);
         } else {
                 $input .= "\n" unless $input =~ /\n$/;
                 my @yaml = Load($input);
                 $self->die_on_invalid_precondition(\@yaml, $schema);
-                return model('TestrunDB')->resultset('Precondition')->add(\@yaml);
+                return $self->schema->resultset('Precondition')->add(\@yaml);
         }
 }
 
 
 sub update {
         my ($self, $id, $condition) = @_;
-        my $precondition = model('TestrunDB')->resultset('Precondition')->find($id);
+        my $precondition = $self->schema->resultset('Precondition')->find($id);
         die "Precondition with id $id not found\n" if not $precondition;
 
         return $precondition->update_content($condition);
@@ -75,7 +68,7 @@ sub update {
 
 sub del {
         my ($self, $id) = @_;
-        my $precondition = model('TestrunDB')->resultset('Precondition')->find($id);
+        my $precondition = $self->schema->resultset('Precondition')->find($id);
         return qq(No precondition with id "$id" found) if not $precondition;;
         $precondition->delete();
         return 0;
@@ -87,7 +80,7 @@ __END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -160,13 +153,23 @@ prevent confusion with the buildin delete function.
 @return success - 0
 @return error   - error string
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 AMD OSRC Tapper Team <tapper@amd64.org>
 
+=item *
+
+Tapper Team <tapper-ops@amazon.com>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2013 by Advanced Micro Devices, Inc..
+This software is Copyright (c) 2016 by Advanced Micro Devices, Inc..
 
 This is free software, licensed under:
 
