@@ -1,10 +1,6 @@
 package Tapper::Cmd::Requested;
-BEGIN {
-  $Tapper::Cmd::Requested::AUTHORITY = 'cpan:TAPPER';
-}
-{
-  $Tapper::Cmd::Requested::VERSION = '4.1.8';
-}
+our $AUTHORITY = 'cpan:TAPPER';
+$Tapper::Cmd::Requested::VERSION = '5.0.0';
 use Moose;
 
 use Tapper::Model 'model';
@@ -15,13 +11,33 @@ use parent 'Tapper::Cmd';
 
 
 sub add_host {
-        my ($self, $id, $hostname) = @_;
-        my $hosts = model('TestrunDB')->resultset('Host')->search({name => $hostname});
-        return if not $hosts->count;
-        my $host_id = $hosts->search({}, {rows => 1})->first->id;
-        my $request = model('TestrunDB')->resultset('TestrunRequestedHost')->new({testrun_id => $id, host_id => $host_id});
-        $request->insert();
-        return $request->id;
+
+    my ( $self, $testrun_id, $i_host_id ) = @_;
+
+    if ( $i_host_id !~ /^\d+$/ ) {
+        if (
+            !(
+                $i_host_id =
+                    model('TestrunDB')
+                        ->resultset('Host')
+                        ->search({ name => $i_host_id },{ rows => 1 })
+                        ->first
+                        ->id
+            )
+        ) {
+            return;
+        }
+    }
+
+    my $or_request =
+        model('TestrunDB')
+            ->resultset('TestrunRequestedHost')
+            ->new({ testrun_id => $testrun_id, host_id => $i_host_id })
+    ;
+    $or_request->insert();
+
+    return $or_request->id;
+
 }
 
 
@@ -42,7 +58,7 @@ __END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -75,8 +91,8 @@ Add a requested host entry to database.
 
 Add a requested host for a given testrun.
 
-@param int    - testrun id
-@param string - hostname
+@param int              - testrun id
+@param string/integer   - hostname or host id
 
 @return success - local id (primary key)
 @return error   - undef
@@ -101,13 +117,23 @@ Copyright 2012 AMD OSRC Tapper Team, all rights reserved.
 
 This program is released under the following license: freebsd
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 AMD OSRC Tapper Team <tapper@amd64.org>
 
+=item *
+
+Tapper Team <tapper-ops@amazon.com>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2013 by Advanced Micro Devices, Inc..
+This software is Copyright (c) 2016 by Advanced Micro Devices, Inc..
 
 This is free software, licensed under:
 
