@@ -1,11 +1,6 @@
 package Tapper::Cmd::Testplan;
-BEGIN {
-  $Tapper::Cmd::Testplan::AUTHORITY = 'cpan:TAPPER';
-}
-{
-  $Tapper::Cmd::Testplan::VERSION = '4.1.8';
-}
-
+our $AUTHORITY = 'cpan:TAPPER';
+$Tapper::Cmd::Testplan::VERSION = '5.0.0';
 use 5.010;
 use Moose;
 
@@ -14,6 +9,8 @@ use Try::Tiny;
 use YAML::Syck;
 use Tapper::Model 'model';
 use Tapper::Reports::DPath::TT;
+use File::Slurp 'slurp';
+use Perl6::Junction 'any';
 
 extends 'Tapper::Cmd';
 
@@ -22,14 +19,19 @@ extends 'Tapper::Cmd';
 sub get_module_for_type
 {
         my ($self, $type) = @_;
-         given (lc($type)){
-                when('multitest') { return "Tapper::Cmd::Testrun"; }
-                default           { $type = ucfirst($type); return "Tapper::Cmd::$type"; }
+        
+        if ( lc($type) eq 'multitest' ) {
+            return "Tapper::Cmd::Testrun";
+        }
+        elsif ( lc($type) eq 'scenario')  {
+            return "Tapper::Cmd::Scenario"
+        }
+        else {
+            $type = ucfirst($type); return "Tapper::Cmd::$type";
         }
 }
 
 
-
 sub add {
         my ($self, $plan_content, $path, $name) = @_;
 
@@ -38,10 +40,11 @@ sub add {
         # print STDERR "plans: ".Dumper($plan_content);
         # print STDERR "plans: ".Dumper(\@plans);
 
-        my $instance = model('TestrunDB')->resultset('TestplanInstance')->new({evaluated_testplan => $plan_content,
-                                                                               path => $path,
-                                                                               name => $name,
-                                                                              });
+        my $instance = model('TestrunDB')->resultset('TestplanInstance')->new({
+            evaluated_testplan => $plan_content,
+            path               => $path,
+            name               => $name,
+        });
         $instance->insert;
 
         my @testrun_ids;
@@ -56,19 +59,19 @@ sub add {
                 };
 
                 my $handler = "$module"->new();
-                my @new_ids = $handler->create($plan->{description}, $instance->id);
+                my $description = $plan->{testplan_description} || $plan->{description};
+                my @new_ids = $handler->create($description, $instance->id);
                 push @testrun_ids, @new_ids;
+
         }
         return $instance->id;
 }
 
 
-
-
 sub del {
         my ($self, $id) = @_;
         my $testplan = model('TestrunDB')->resultset('TestplanInstance')->find($id);
-        foreach my $testrun ($testplan->testruns->all) {
+        while(my $testrun = $testplan->testruns->next) {
                 if ($testrun->testrun_scheduling->status eq 'running') {
                         my $message = model('TestrunDB')->resultset('Message')->new({testrun_id => $testrun->id,
                                                                                      type       => 'state',
@@ -110,84 +113,79 @@ sub parse_path
         return $path;
 }
 
+sub get_shortname {
 
-sub get_shortname{
-        my ($self, $plan, $name) = @_;
-        return $name if $name;
+    my ( $or_self, $s_plan ) = @_;
 
-        foreach my $line (split "\n", $plan) {
-                if ($line =~/^###\s*(?:short)?name\s*:\s*(.+)$/i) {
-                        return $1;
-                }
+    foreach my $s_line ( split /\n/, $s_plan ) {
+        if ( $s_line =~ /^\s*-?\s*(?:short)?name\s*:\s*(.+?)\s*$/i ) {
+            return $1;
         }
-        return;
+    }
+
+    return;
+
+}
+
+
+sub guide
+{
+        my ($self, $file, $substitutes, $include) = @_;
+        my $text;
+        my $guide = $self->apply_macro($file,
+                                       $substitutes,
+                                       $include);
+
+        my @guide = grep { m/^###/ } split (qr/\n/, $guide);
+        $text = "Self-documentation:\n";
+        $text = join "\n", map { my $l = $_; $l =~ s/^###/ /; "$l" } @guide;
+        return $text;
 }
 
 
 sub testplannew {
         my ($self, $opt) = @_;
 
-        use File::Slurp 'slurp';
-
-        my $file = $opt->{file};
-
-        my $plan = slurp($file);
-        $plan = $self->apply_macro($plan,
-                                   {
-                                    HOME => $ENV{HOME},
-                                    %{$opt->{D} || {}},
-                                   },
-                                   $opt->{include});
-
-        if ($opt->{guide}) {
-                my $guide = $plan;
-                my @guide = grep { m/^###/ } split (qr/\n/, $plan);
-                say "Self-documentation:";
-                say map { my $l = $_; $l =~ s/^###/ /; "$l\n" } @guide;
-                return 0;
-        }
-
-        my $cmd = Tapper::Cmd::Testplan->new;
+        my $plan = $self->apply_macro($opt->{file}, $opt->{substitutes}, $opt->{include});
         my $path = $opt->{path} || $self->parse_path($opt->{file});
-        my $shortname = $self->get_shortname($plan, $opt->{name});
-
-        if ($opt->{dryrun}) {
-                say $plan;
-                return 0;
-        }
-
-        my $plan_id = $cmd->add($plan, $path, $shortname);
-        die "Plan not created" unless defined $plan_id;
-
-        if ($opt->{verbose}) {
-                my $url = Tapper::Config->subconfig->{base_url} || 'http://tapper/tapper';
-                say "Plan created";
-                say "  id:   $plan_id";
-                say "  url:  $url/testplan/id/$plan_id";
-                say "  path: $path";
-                say "  file: ".$opt->{file};
-        } else {
-                say $plan_id;
-        }
-        return 0;
+        my $name = $self->get_shortname($plan);
+        return $self->add($plan, $path, $name);
 }
 
 
-sub apply_macro
+sub status
 {
-        my ($self, $macro, $substitutes, $includes) = @_;
+        my ($self, $id) = @_;
+        my $results = model('TestrunDB')->fetch_raw_sql({
+                                                        query_name  => 'testplans::testplan_status',
+                                                        fetch_type  => '$%',
+                                                        query_vals  => {testplan_id => $id},
+                                                       });
+        my $testruns_rs = model->resultset("Testrun")->search({testplan_id => $id});
+        my %testrun_ids = map { $_->id => $_->topic_name} $testruns_rs->all;
+        $results->{testruns} = \%testrun_ids;
+        return $results;
 
-        my @include_paths = (Tapper::Config->subconfig->{paths}{testplan_path});
-        push @include_paths, @{$includes || [] };
-        my $include_path_list = join ":", @include_paths;
-
-        my $tt = Tapper::Reports::DPath::TT->new(include_path => $include_path_list,
-                                                 substitutes  => $substitutes,
-                                                );
-        return $tt->render_template($macro);
+# TODO check how we can get old infos back in
+# * status - one of 'schedule', 'running', 'pass', 'fail'
+# * complete_percentage - percentage of finished testruns
+# * started_percentage  - percentage of running and finished testruns
+# * success_percentage  - average of success rates of finished testruns
 }
 
 
+sub testplan_files
+{
+        my ($self, $testplan_id, $filter) = @_;
+        my $results_rawsql = model('TestrunDB')->fetch_raw_sql({
+                                                                query_name  => 'testplans::reportfile',
+                                                                fetch_type  => '@@',
+                                                                query_vals  => {testplan_id => $testplan_id, filter => $filter},
+                                                               });
+        my @results = map { $_->[0] } @$results_rawsql;
+        return \@results;
+}
+
 
 1; # End of Tapper::Cmd::Testplan
 
@@ -195,7 +193,7 @@ __END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -277,38 +275,81 @@ since we do not simply want the dirname but kind of an "un-prefix".
 
 @return string - test plan path
 
-=head2 get_shortname
+=head2 guide
 
-Get the shortname for this testplan. The shortname is either given as
-command line option or inside the plan text.
+Get self documentation of a testplan file.
 
-@param string - plan text
-@param string - value of $opt->{name}
+@param string - file name of testplan file
 
-@return string - shortname
+@return success - documentation text
+
+@throws - die()
 
 =head2 testplannew
 
 Create a testplan instance from a file.
 
-=head2 apply_macro
+@param hash ref - options containing
 
-Process macros and substitute using Template::Toolkit.
+required:
+* file: string, path of the testplan file
+* substitutes: hash ref, substitute variables for Template Toolkit
 
-@param string  - contains macros
-@param hashref - containing substitutions
-@optparam string - path to more include files
+optional:
+* include: array ref of strings containing include paths
+* path: string, alternative path instead of real path
+* name: string, overwrite shortname in plan
 
-@return success - text with applied macros
-@return error   - die with error string
+@return success - testplan id
 
-=head1 AUTHOR
+@throws die
+
+=head2 status
+
+Get information of one testplan.
+
+@param int - testplan id
+
+@return - hash ref -
+* count_fail      0,
+* count_pass      2,
+* count_pending   0,
+* name            "HWXYZ",
+* path            undef,
+* testplan_date   "2014-03-24",
+* testplan_id     1040,
+* testplan_time   "14:17"
+
+@throws - die
+
+=head2 testplan_files
+
+Get all files that belong to a testplan.
+
+@param int    - testplan id
+@param string - filter
+
+@return array ref - list of report file ids
+
+@throws - die
+
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 AMD OSRC Tapper Team <tapper@amd64.org>
 
+=item *
+
+Tapper Team <tapper-ops@amazon.com>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2013 by Advanced Micro Devices, Inc..
+This software is Copyright (c) 2016 by Advanced Micro Devices, Inc..
 
 This is free software, licensed under:
 
